@@ -141,30 +141,44 @@ class Storage(driver.Base):
             raise exceptions.FileNotFoundError("File not found %s" % path)
         
     def stream_write(self, path, fp):
-        logger.info("stream_write path:%s" % path)
-        path1 = self._init_path(path)
-        part_size = 5 * 1024 * 1024
-        if self.buffer_size < part_size:
-            part_size = self.buffer_size
-        
-        try:
-            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir="/tmp")
-            with open(tmp_file, 'w') as f:
-                while True:
-                    buf = fp.read(part_size)
-                    if not buf: break
-                    f.write(buf)
-                
-            with open(tmp_file, 'r') as fp:
-                object_instance = self._jss.bucket(self._bucket).object(path1)
-                object_instance.multi_upload_fp(None, fp, part_size)
-                
-        except Exception as e :
-             logger.error("stream_write error:%s" % e)
-             raise e
-        finally:
-            if os.path.exists(tmp_file):
-                os.remove(tmp_file)
+         logger.info("stream_write path:%s" % path)
+         path1 = self._init_path(path)
+         part_size = 5 * 1024 * 1024
+         
+         if self.buffer_size < part_size:
+             part_size = self.buffer_size
+         try:
+             object_instance = self._jss.bucket(self._bucket).object(path1)
+             object_instance.multi_upload_fp_with_size(None, fp, self.buffer_size, part_size)
+         except Exception as e :
+            logger.error("stream_write error:%s" % e)
+            raise e
+         
+#    def stream_write(self, path, fp):
+#        logger.info("stream_write path:%s" % path)
+#        path1 = self._init_path(path)
+#        part_size = 5 * 1024 * 1024
+#        if self.buffer_size < part_size:
+#            part_size = self.buffer_size
+#        
+#        try:
+#            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir="/tmp")
+#            with open(tmp_file, 'w') as f:
+#                while True:
+#                    buf = fp.read(part_size)
+#                    if not buf: break
+#                    f.write(buf)
+#                
+#            with open(tmp_file, 'r') as fp:
+#                object_instance = self._jss.bucket(self._bucket).object(path1)
+#                object_instance.multi_upload_fp(None, fp, part_size)
+#                
+#        except Exception as e :
+#             logger.error("stream_write error:%s" % e)
+#             raise e
+#        finally:
+#            if os.path.exists(tmp_file):
+#                os.remove(tmp_file)
         
 
     @lru.remove
